# `gnomonicus` tests

To aid development and to seed unit testing, a small number of inputs and outputs are provided, all based on the SARS-CoV-2 genome `NC_045512.2`.

An entirely fictious catalogue adhering to the GARC1 grammar has been created, allowing for "resistance predictions".

## S@S484K

Input:
    NC_045512.2-S_N484K-minos.vcf
Expect output:
    variants:    23012g>a
    mutations:   S@E484K
    predictions: {'AAA': 'R', 'BBB': 'S'}

## S@F2F

Input:
    NC_045512.2-S_F2F-minos.vcf
Expect output:
    variants:    21568t>c
    mutations:   S@F2F
    predictions: {'AAA': 'S', 'BBB': 'S'}

## S@F2L

Input:
    NC_045512.2-S_F2L-minos.vcf
Expect output:
    variants:    21566t>c
    mutations:   S@F2L
    predictions: {'AAA': 'U', 'BBB': 'S'}

## S@200_ins_1

Input:
    NC_045512.2-S_200_indel-minos.vcf
Expect output:
    variants:    21762_indel, 21762_ins_1, 21762_ins_c
    mutations:   S@200_indel, S@200_ins_1, S@200_ins_c
    predictions: {'AAA': 'R', 'BBB': 'S'}

## Double mutation in overlap between ORF7a and ORF7b

Input:
    NC_045512.2-double-minos.vcf
Expect output:
    variants:    27758g>c
    mutations:   ORF7a!122S, ORF7b@M1I
    predictions: {'AAA': 'R', 'BBB': 'R'}

## Multi-mutation

Input:
    NC_045512.2-S_E484K&1450_ins_a-minos.vcf
Expected output:
    variants:    23012g>a, 23012_ins_a, 23012_indel, 23012_ins_1
    mutations:   S@E484K, S@1450_ins_a, S@1450_ins_a&S@E484K, S@1450_indel, S@1450_ins_1
    predictions: {'AAA': 'R', 'BBB': 'R'}




